@@ -19,6 +19,7 @@ class ArthurOAuthSessionAPIConfiguration(Configuration):
         self,
         session: ArthurAPISession,
         leeway_seconds: int = 30,
+        verify_ssl: bool = True,
         *args: Any,
         **kwargs: Any,
     ) -> None:
@@ -26,6 +27,7 @@ class ArthurOAuthSessionAPIConfiguration(Configuration):
         super().__init__(*args, host=host, **kwargs)
         self.session = session
         self.leeway_seconds = leeway_seconds
+        self.verify_ssl = verify_ssl
         self.logger = logging.getLogger(__name__)
 
     @property
